OC.L10N.register(
    "forms",
    {
    "Timestamp of data load" : "Ma'lumotlarni yuklash vaqt belgisi",
    "No" : "No",
    "Yes" : "Yes",
    "Count" : "Hisoblash",
    "Copy" : "Copy",
    "Shared with you" : "Shared with you",
    "Results" : "Natijalar",
    "Cancel" : "Bekor qilish",
    "Options" : "Variantlar",
    "Delete" : "O'chirish",
    "Other" : "Boshqa",
    "never" : "hech qachon",
    "Set expiration date" : "Set expiration date",
    "Share link" : "Share link",
    "Copy embedding code" : "O'rnatish kodini nusxalash",
    "Internal link" : "Ichki havola",
    "View" : "Ko'rish",
    "Edit" : "Tahrirlash",
    "Share" : "Ulashish",
    "Description" : "Tavsif",
    "Download" : "Yuklab olish",
    "Search" : "Qidirish",
    "No results found" : "Hech qanday natija topilmadi",
    "Sharing" : "Ulashish",
    "Settings" : "Sozlamalar",
    "Submit" : "Submit",
    "Checkboxes" : "Belgilash katakchalari",
    "File" : "File",
    "Date" : "Sana",
    "Pick a date" : "Sana tanlang",
    "Time" : "Vaqt",
    "Pick a time" : "Vaqtni tanlang",
    "Color" : "Rang",
    "Text" : "Matn",
    "Email address" : "E-pochta manzili",
    "Uploading …" : "Yuklanmoqda..."
},
"nplurals=1; plural=0;");
